==> reference_cmsplugin-0.4.2.tar.gz: reference_cmsplugin-0.4.2/reference_cmsplugin/admin.py <==
# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.html import format_html
from django.conf import settings

from .models import Category, Reference

if 'ckeditor' in settings.INSTALLED_APPS:
    from ckeditor.fields import RichTextFormField
else:
    RichTextFormField = None


class CategoryAdmin(admin.ModelAdmin):
    list_display = [
        'name',
        'order',
        'enabled',
    ]


class ReferenceAdmin(admin.ModelAdmin):
    list_display = [
        'name',
        'link',
        'image_url',
        'order',
        'enabled',
    ]
    list_filter = [
        'categories',
    ]

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'description':
            kwargs.update(
                widget=None,
                form_class=RichTextFormField,
            )
        return super(ReferenceAdmin, self).formfield_for_dbfield(db_field, **kwargs)

    def image_url(self, reference):
        if not reference.image:
            return ''
        return format_html('<img style="height: 1em" src="{}" alt="{repr}" />{repr}',
                           reference.image.url,
                           repr=str(reference))


if 'adminsortable2' in settings.INSTALLED_APPS:
    from adminsortable2.admin import SortableAdminMixin
    CategoryAdmin = type(CategoryAdmin)('CategoryAdmin', (SortableAdminMixin, CategoryAdmin), {})
    ReferenceAdmin = type(ReferenceAdmin)('ReferenceAdmin', (SortableAdminMixin, ReferenceAdmin), {})


admin.site.register(Category, CategoryAdmin)
admin.site.register(Reference, ReferenceAdmin)

==> reference_cmsplugin-0.4.6.tar.gz: reference_cmsplugin-0.4.6/reference_cmsplugin/admin.py <==
# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.html import format_html
from django.conf import settings

from .models import Category, Reference

if 'ckeditor' in settings.INSTALLED_APPS:
    from ckeditor.fields import RichTextFormField
else:
    RichTextFormField = None

if 'modeltranslation' in settings.INSTALLED_APPS:
    from modeltranslation.admin import TranslationAdmin, TranslationTabularInline
    BaseModelAdmin = TranslationAdmin
    BaseTabularInline = TranslationTabularInline
else:
    BaseModelAdmin = admin.ModelAdmin
    BaseTabularInline = admin.TabularInline


class CategoryAdmin(admin.ModelAdmin):
    list_display = [
        'name',
        'order',
        'enabled',
    ]


class ReferenceAdmin(BaseModelAdmin):
    list_display = [
        'name',
        'link',
        'image_url',
        'order',
        'enabled',
    ]
    list_filter = [
        'categories',
    ]

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'description':
            kwargs.update(
                widget=None,
                form_class=RichTextFormField,
            )
        return super(ReferenceAdmin, self).formfield_for_dbfield(db_field, **kwargs)

    def image_url(self, reference):
        if not reference.image:
            return ''
        return format_html('<img style="height: 1em" src="{}" alt="{repr}" />{repr}',
                           reference.image.url,
                           repr=str(reference))


if 'adminsortable2' in settings.INSTALLED_APPS:
    from adminsortable2.admin import SortableAdminMixin
    CategoryAdmin = type(CategoryAdmin)('CategoryAdmin', (SortableAdminMixin, CategoryAdmin), {})
    ReferenceAdmin = type(ReferenceAdmin)('ReferenceAdmin', (SortableAdminMixin, ReferenceAdmin), {})


admin.site.register(Category, CategoryAdmin)
admin.site.register(Reference, ReferenceAdmin)
